wags_tails.utils.storage
========================

.. automodule:: wags_tails.utils.storage
   :members:
   :undoc-members:
   :special-members: __init__
   :exclude-members: model_fields, model_config
